@@ -15,13 +15,7 @@ dparserPtrIni
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
 #include <Rmath.h>
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("nonmem2rx", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 
 sbuf curLine;
 
